==> gimp-1.1.18.tar.bz2: gimp-1.1.18/app/by_color_select.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#ifndef __BY_COLOR_SELECT_H__
#define __BY_COLOR_SELECT_H__

#include "tools.h"
#include "gdisplayF.h"
#include "gimage.h"

Tool * tools_new_by_color_select           (void);
void   tools_free_by_color_select          (Tool         *tool);

void   by_color_select_initialize          (GDisplay     *gdisp);
void   by_color_select_initialize_by_image (GImage       *gimage);

void   by_color_select                     (GimpImage    *gimage,
					    GimpDrawable *drawable,
					    guchar       *color,
					    gint          threshold,
					    gint          op,
					    gint          antialias,
					    gint          feather,
					    gdouble       feather_radius,
					    gint          sample_merged);

#endif  /*  __BY_COLOR_SELECT_H__  */

==> gimp-1.2.3.tar.bz2: gimp-1.2.3/app/by_color_select.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#ifndef __BY_COLOR_SELECT_H__
#define __BY_COLOR_SELECT_H__

#include "tools.h"
#include "gdisplayF.h"
#include "gimage.h"

Tool * tools_new_by_color_select           (void);
void   tools_free_by_color_select          (Tool         *tool);

void   by_color_select_initialize          (GDisplay     *gdisp);
void   by_color_select_initialize_by_image (GImage       *gimage);

void   by_color_select                     (GimpImage    *gimage,
					    GimpDrawable *drawable,
					    guchar       *color,
					    gint          threshold,
					    SelectOps     op,
					    gboolean      antialias,
					    gboolean      feather,
					    gdouble       feather_radius,
					    gboolean      sample_merged);

#endif  /*  __BY_COLOR_SELECT_H__  */
